@@ -9,7 +9,7 @@
 
 G_BEGIN_DECLS
 
-extern GType crux_type_style;
+extern GType crux_type_style G_GNUC_INTERNAL;
 
 #define CRUX_TYPE_STYLE              crux_type_style
 #define CRUX_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), CRUX_TYPE_STYLE, CruxStyle))
@@ -32,7 +32,7 @@ struct _CruxStyleClass
 
 };
 
-void crux_style_register_type (GTypeModule *module);
+void crux_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
 
 G_END_DECLS
 
