@@ -18,6 +18,7 @@
 #include "industrial_style_versioned_include.h"
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
 
 #define DETAIL(xx)   ((detail) && (!strcmp((xx), detail)))
 #if INDUSTRIAL_GTK_VERSION == 2
@@ -528,13 +529,11 @@ ensure_pixmap (GtkStyle *style, GdkWindow *window, Shading *shading, int pixmap)
     char **xpm_copy;
     int colors;
     int height;
-    int width;
     int i;
 
     xpm = pixmaps[pixmap];
     first_line = g_strsplit (xpm[0], " ", 0);
 
-    width = atoi (first_line[0]);
     height = atoi (first_line[1]);
     colors = atoi (first_line[2]);
 
@@ -597,18 +596,6 @@ get_color (GtkStyle *style, GdkColor *bg_color, GdkColor *fg_color, int shade)
   return &shading->colors[shade];
 }
 
-static GdkGC *
-get_gray_gc (GtkStyle *style, int shade)
-{
-  return get_gc (style, &style->bg[GTK_STATE_NORMAL], &style->fg[GTK_STATE_NORMAL], shade);
-}
-
-static GdkColor *
-get_gray_color (GtkStyle *style, int shade)
-{
-  return get_color (style, &style->bg[GTK_STATE_NORMAL], &style->fg[GTK_STATE_NORMAL], shade);
-}
-
 static gboolean 
 sanitize_size (GdkWindow      *window,
 	       gint           *width,
@@ -904,28 +891,6 @@ draw_rounded_rect_two_pixel (GdkWindow *window,
   kaleidoscope_point (window, corner_gc, area, x, y, width, height, 0, 1);
 }
 
-static void
-draw_dot (GdkWindow *window,
-	  GdkGC *gc,
-	  GtkOrientation orientation,
-	  int x_base,
-	  int y_base,
-	  int first_offset,
-	  int second_offset)
-{
-  if (orientation == GTK_ORIENTATION_HORIZONTAL) {
-    gdk_draw_point (window,
-		    gc,
-		    x_base + first_offset,
-		    y_base + second_offset);
-  } else {
-    gdk_draw_point (window,
-		    gc,
-		    x_base + second_offset,
-		    y_base + first_offset);
-  }
-}
-
   /* #define names assume vertical */
 #define HANDLE_HEIGHT (4 * 4 + 1 + 2)
 #define HANDLE_WIDTH (4 + 1 + 2)
@@ -1012,7 +977,7 @@ draw_hline (GtkStyle     *style,
 {
   GdkGC *gc;
   
-#if DEBUG
+#ifdef DEBUG
   printf ("draw_hline: %p %p %s %i %i %i\n", widget, window, detail, x1, x2,
 	  y);
 #endif
@@ -1075,7 +1040,7 @@ draw_handle (GtkStyle      *style,
   
   sanitize_size (window, &width, &height);
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, orientation);
 #endif
@@ -1160,7 +1125,7 @@ draw_vline (GtkStyle     *style,
 {
   GdkGC *gc;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i\n", __FUNCTION__, widget, window, detail, y1, y2,
 	  x);
 #endif
@@ -1198,7 +1163,7 @@ draw_slider (GtkStyle      *style,
 {
   int handle_width, handle_height;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, orientation);
 #endif
@@ -1341,7 +1306,6 @@ real_draw_box (GtkStyle      *style,
 
     GdkGC *gc;
     GdkColor *color;
-    int gradient_lines = 7;
 
     if (! (GTK_WIDGET_HAS_DEFAULT (widget) &&
 	   GTK_IS_BUTTON (widget) && 
@@ -1708,10 +1672,9 @@ real_draw_box (GtkStyle      *style,
 	bg_color = get_color (style, &style->bg[state_type], &style->fg[state_type], SHADE_BG);
 	corner_gc = get_gc (style, bg_color, fg_color, SHADE_HALF);
       }
+      draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc,
+				   area, x, y, width, height);
     }
-
-    draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc,
-				 area, x, y, width, height);
   } else if (DETAIL("menubar")) {
     GdkGC *bg_gc;
     GdkGC *fg_gc;
@@ -1834,7 +1797,7 @@ draw_box (GtkStyle      *style,
 	  gint           width,
 	  gint           height)
 {
-#if DEBUG
+#ifdef DEBUG
   printf ("draw_box: %p %p %s %i %i %i %i\n", widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -1865,7 +1828,7 @@ draw_shadow (GtkStyle        *style,
 	     gint             width,
 	     gint             height)
 {
-#if DEBUG
+#ifdef DEBUG
   printf ("draw_shadow: %p %p %s %i %i %i %i\n", widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -1972,7 +1935,7 @@ draw_box_gap (GtkStyle       *style,
 	      gint            gap_x,
 	      gint            gap_width)
 {
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -2029,7 +1992,7 @@ draw_shadow_gap (GtkStyle       *style,
 		 gint            gap_x,
 		 gint            gap_width)
 {
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -2061,7 +2024,7 @@ draw_extension (GtkStyle       *style,
   GdkColor *fg_color;
   GdkGC *corner_gc;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -2272,7 +2235,7 @@ draw_arrow (GtkStyle      *style,
 {
   gint original_width, original_x;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2351,7 +2314,7 @@ draw_check (GtkStyle		*style,
 
   GdkColor *fg, *bg;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2411,7 +2374,7 @@ draw_option (GtkStyle		*style,
   int which;
   GdkColor *fg, *bg;
 
-#if DEBUG
+#ifdef DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2720,4 +2683,142 @@ draw_focus (GtkStyle      *style,
 }
 #endif
 
+#if INDUSTRIAL_GTK_VERSION == 2
+static GdkPixbuf *
+set_transparency (const GdkPixbuf *pixbuf, gdouble alpha_percent)
+{
+	GdkPixbuf *target;
+	guchar *data, *current;
+	guint x, y, rowstride, height, width;
+
+	g_return_val_if_fail (pixbuf != NULL, NULL);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
+
+	/* Returns a copy of pixbuf with it's non-completely-transparent pixels to
+	   have an alpha level "alpha_percent" of their original value. */
+
+	target = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
+
+	if (alpha_percent == 1.0)
+		return target;
+	width = gdk_pixbuf_get_width (target);
+	height = gdk_pixbuf_get_height (target);
+	rowstride = gdk_pixbuf_get_rowstride (target);
+	data = gdk_pixbuf_get_pixels (target);
+
+	for (y = 0; y < height; y++) {
+		for (x = 0; x < width; x++) {
+			/* The "4" is the number of chars per pixel, in this case, RGBA,
+			   the 3 means "skip to the alpha" */
+			current = data + (y * rowstride) + (x * 4) + 3; 
+			*(current) = (guchar) (*(current) * alpha_percent);
+		}
+	}
+
+	return target;
+}
+
+static GdkPixbuf*
+scale_or_ref (GdkPixbuf *src,
+              int width,
+              int height)
+{
+	if (width == gdk_pixbuf_get_width (src) &&
+	    height == gdk_pixbuf_get_height (src)) {
+		return g_object_ref (src);
+	} else {
+		return gdk_pixbuf_scale_simple (src,
+						width, height,
+						GDK_INTERP_BILINEAR);
+	}
+}
+
+static GdkPixbuf *
+render_icon (GtkStyle            *style,
+	     const GtkIconSource *source,
+	     GtkTextDirection     direction,
+	     GtkStateType         state,
+	     GtkIconSize          size,
+	     GtkWidget           *widget,
+	     const char          *detail)
+{
+	int width = 1;
+	int height = 1;
+	GdkPixbuf *scaled;
+	GdkPixbuf *stated;
+	GdkPixbuf *base_pixbuf;
+	GdkScreen *screen;
+	GtkSettings *settings;
+	
+	/* Oddly, style can be NULL in this function, because
+	 * GtkIconSet can be used without a style and if so
+	 * it uses this function.
+	 */
+	
+	base_pixbuf = gtk_icon_source_get_pixbuf (source);
+	
+	g_return_val_if_fail (base_pixbuf != NULL, NULL);
+	
+	if (widget && gtk_widget_has_screen (widget)) {
+		screen = gtk_widget_get_screen (widget);
+		settings = gtk_settings_get_for_screen (screen);
+	} else if (style->colormap) {
+		screen = gdk_colormap_get_screen (style->colormap);
+		settings = gtk_settings_get_for_screen (screen);
+	} else {
+		settings = gtk_settings_get_default ();
+		GTK_NOTE (MULTIHEAD,
+			  g_warning ("Using the default screen for gtk_default_render_icon()"));
+	}
+	
+  
+	if (size != (GtkIconSize) -1 && !gtk_icon_size_lookup_for_settings (settings, size, &width, &height)) {
+		g_warning (G_STRLOC ": invalid icon size '%d'", size);
+		return NULL;
+	}
+
+	/* If the size was wildcarded, and we're allowed to scale, then scale; otherwise,
+	 * leave it alone.
+	 */
+	if (size != (GtkIconSize)-1 && gtk_icon_source_get_size_wildcarded (source))
+		scaled = scale_or_ref (base_pixbuf, width, height);
+	else
+		scaled = g_object_ref (base_pixbuf);
+	
+	/* If the state was wildcarded, then generate a state. */
+	if (gtk_icon_source_get_state_wildcarded (source)) {
+		if (state == GTK_STATE_INSENSITIVE) {
+			stated = set_transparency (scaled, 0.3);
+#if 0
+			stated =
+				gdk_pixbuf_composite_color_simple (scaled,
+								   gdk_pixbuf_get_width (scaled),
+								   gdk_pixbuf_get_height (scaled),
+								   GDK_INTERP_BILINEAR, 128,
+								   gdk_pixbuf_get_width (scaled),
+								   style->bg[state].pixel,
+								   style->bg[state].pixel);
+#endif
+			gdk_pixbuf_saturate_and_pixelate (stated, stated,
+							  0.1, FALSE);
+			
+			g_object_unref (scaled);
+		} else if (state == GTK_STATE_PRELIGHT) {
+			stated = gdk_pixbuf_copy (scaled);      
+			
+			gdk_pixbuf_saturate_and_pixelate (scaled, stated,
+							  1.2, FALSE);
+			
+			g_object_unref (scaled);
+		} else {
+			stated = scaled;
+		}
+	}
+	else
+		stated = scaled;
+  
+  return stated;
+}
+#endif
+
 #include "industrial_style_versioned_code.h"
